'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.error = error;
exports.warning = warning;
var errorStyles = 'padding: 2px; font-weight: bold; background: red; color: black';
var warningStyles = 'padding: 2px; font-weight: bold; background: gold; color: black';

function formatMessage(type, messageBody, moduleName, modulePath) {
  var header = '%c -- ' + type + ' --------------------------------------------------- ' + modulePath + ' -- ';

  var body = '%c\n\n\n' + moduleName + ' %c' + messageBody + '\n\n  ';

  var info = '%c\nPlease see the documentation at %chttps://www.polished.js.org/#' + moduleName + ' %cfor more information.\n\n  ';

  return '' + header + body + info;
}

function generateHeaderStyles(type) {
  return type === 'error' ? errorStyles : warningStyles;
}

/**
 * Handles the formatting of warnings and errors generated by modules.
 * @private
 */

function messageHandler(type, messageBody, moduleName, modulePath) {
  var message = formatMessage(type, messageBody, moduleName, modulePath);
  var headerStyles = generateHeaderStyles(type);
  // eslint-disable-next-line no-console
  console.log(message, headerStyles, 'color: black', 'color: slategray; font-weight: bold', 'color: slategray', 'color: blue', 'color: slategray');
}

function getCaller() {
  var file = void 0;
  var frame = void 0;

  var pst = Error.prepareStackTrace;
  Error.prepareStackTrace = function (_, stack) {
    Error.prepareStackTrace = pst;
    return stack;
  };
  // eslint-disable-next-line prefer-destructuring
  var stack = new Error().stack;
  stack = stack.slice(2);

  do {
    // $FlowFixMe
    frame = stack.shift();
    file = frame && frame.getFileName();
  } while (stack.length && file === 'module.js');

  return file;
}

function getModuleInfo(callerModule) {
  var moduleName = callerModule.match(/([^/]+)(?=\.\w+$)/)[0];
  var callerArray = callerModule.split('/');
  var modulePath = callerArray[callerArray.length - 2] + '/' + callerArray[callerArray.length - 1];
  return [moduleName, modulePath];
}

function error(messageBody) {
  messageHandler.apply(undefined, ['error', messageBody].concat(getModuleInfo(getCaller())));
}

function warning(messageBody) {
  messageHandler.apply(undefined, ['warning', messageBody].concat(getModuleInfo(getCaller())));
}